%--------------------------------------------
% Function clean_onoff
% Input: x0 - binary (up/not up or down/not down) activity from all neurons
% Outputs: x_clean - binary activity from all neurons where all up (down) states 
%                   less than min_ln apart are merged and all remaining up (down) 
%                   states shorter than min_ln are eliminated. 
%                   See Volgushev (2011) doi: 10.1016/B978-0-444-53839-0.00012-0
%--------------------------------------------

function x_clean = clean_onoff(x0, min_ln)
    n_rows = size(x0,1);
    %x_merged=nan(size(x0));
    x_clean=nan(size(x0));                           

    for i_r=1:n_rows
        x = x0(i_r,:);
        x_m= clean_onoff(x,min_ln, 1);
        %x_merged(i_r,:)=x_m;
        x_clean(i_r,:) = clean_onoff(x_m,min_ln,0);
    end

    function x_f = clean_onoff(x, min_ln, merge)
        ncol=size(x,1);
        x_cross = [zeros(ncol,1) diff(x,1,2)]~=0;
        x_cross_ind=find(x_cross); %indices of crossing to UP or DOWN
        x_cross_merge = diff(x_cross_ind)<min_ln; % if distance less than min, merge
        
        x_blocks = cumsum(x_cross,2);
        b_merge=x_blocks(x_cross_ind(x_cross_merge)); % these blocks should be merged to the next
        
        x_up=ismember(x_blocks,b_merge);
        x_f = x;
        if merge==1
            x_f(x_up)=1;
        elseif merge==0
            x_f(x_up)=0;
        else
            disp('Select 1 or 0 to merge or erase short upstates')
        end
    end
end