%--------------------------------------------------------------------------
% sampleparcels.m
% Identify 10 parcels, each belonging to one of 10 functional networks, and
% choose a column that is central to each parcel.
%--------------------------------------------------------------------------
%close all

% Note: I cannot reproduce functional networks in Rosen and Halgren.
% Parcel-network assignment is taken from paper and seems consistent, so
% perhaps it's parcel-column assignment or the plotting of columns that is
% inconsistent

doplots=0;
loaddata = 1;

addpath('functions', 'files');
if loaddata
    %close all
    % Add paths for general files and functions
    addpath('/bazhlab/mnavaszu/meg/matlab/files',... % general files
    '/bazhlab/mnavaszu/meg/matlab/functions',...    % general functions
    '/bazhlab/mnavaszu/meg/matlab/plot_voltages/files',... % specific files
    '/bazhlab/mnavaszu/meg/matlab/plot_voltages/functions'... % specific functions
    );
    load parcels.csv
    load parcelOrder_and_networkAssignment
    load dist_mat
    %% load ico5 surfaces and parcel identities
    srf = struct;
    mObj = matfile('files/ico5_pial_surf_lh.mat');
    srf = mObj.srf;
end
%%
% Find colorblind-friendly scheme
% https://colorbrewer2.org/?type=diverging&scheme=PuOr&n=11
clcol = [
    255, 255, 255;
        171,217,233;
        116,173,209;
        69,117,180;
        49,54,149;
        0,0,0;
        165,0,38;
        215,48,39;
        244,109,67;
        253,174,97;
        %254,224,144;
        254,210,0;
    0,255,0
    ]/255;

%
idx_nwk = zeros(10242,1); % vector of cols assigned to network
idx_prc =idx_nwk; % vector of cols assigned to parcel
idx_col =idx_nwk;
idx_brd = idx_nwk;

ngroups = 10;
rval = 0.005; % within 5mm
rval_border = rval+0.002;
% Choose 1 parcel in each network
v_prc_nbr = [3 9 26 7 2 16 2 19 5 3]; % index of parcels within network
v_col_nbr = [1 13 73 2 4 10 4 1 4 1 ];
%
% Identify columns in 10 spread-out parcels
for i_p = 1:ngroups %for each network
    prc_nwk=find(postReorderingNetworkIndex==i_p); %find permuted parcels in network
    prc_original=find(ismember(networkOrder,prc_nwk)); %find original parcels in network
    prc = prc_original(v_prc_nbr(i_p)); %take one of parcels in network
    %prc = prc_original;
    cols_prc=find(ismember(parcels, prc)); %cols that belong to that parcel
    cols_prc_all=find(ismember(parcels, prc_original)); %cols that belong to that parcel

    idx_prc(cols_prc)=i_p; %give those cols a unique strength
    idx_nwk(cols_prc_all)=i_p;

    col_id = cols_prc(v_col_nbr(i_p)); % one column in each parcel
    idx_prc(col_id) = 11;

    %% Identify radius region
    % closest to col_id
    onecell = dist_mat(col_id,:);
    radiusvec = find((onecell <= rval).*(onecell>=0)); %exclude negative distances (medial wall)
    radiusvec_border = find((onecell <= rval_border).*(onecell>=0));
    idx_prc(radiusvec)=11;
    idx_brd(radiusvec_border)=11;
    idx_brd(radiusvec)=i_p;
    idx_col(radiusvec)=i_p;
    
end

if doplots
close all
    %% plot networks
    f=figure('Units', 'centimeters', 'Color', 'w');
    f.Position(3:4)=[20,15];
    set(gcf,'color','w')
    tiledlayout(2,2)

    nexttile
    tH = triplot(srf.pial.vertices,srf.pial.faces,idx_nwk);
    view(-90,0)
    tH.FaceColor='Flat';
    camlight headlight;material dull;lighting gouraud; %delete(findobj(gca,'type','light'));
    colormap(clcol);
    clim([0,ngroups+1]);
    axis tight
    %% plot parcels
    nexttile
    tH = triplot(srf.pial.vertices,srf.pial.faces,idx_prc);
    view(-90,0)
    tH.FaceColor='Flat';
    camlight headlight;material dull;lighting gouraud; %delete(findobj(gca,'type','light'));
    colormap(clcol);
    axis tight


    %% plot neighborhoods
    nexttile
    tH = triplot(srf.pial.vertices,srf.pial.faces,idx_col);
    view(-90,0)
    tH.FaceColor='Flat';
    camlight headlight;material dull;lighting gouraud; %delete(findobj(gca,'type','light'));
    colormap(clcol);
    clim([0,ngroups+2]);
    axis tight


        %% plot neighborhoods with border
    nexttile
    tH = triplot(srf.pial.vertices,srf.pial.faces,idx_brd);
    view(-90,0)
    tH.FaceColor='Flat';
    camlight headlight;material dull;lighting gouraud; %delete(findobj(gca,'type','light'));
    colormap(clcol);
    cb=colorbar('southoutside');
    clim([0,ngroups+2]);
    cb.Ticks = 0.5:1:ngroups+1+0.5;
    cb.TickLabels = num2str([0:ngroups+1]');
    cb.TickLength = 0;
    axis tight

   saveas(gcf, ['./figures/lfps/areas/regionselection_' num2str(ngroups) 'cl.png']);

end